#!/bin/bash
#
# all sources: http://zenwalk.pinguix.com/user-accounts/stillborn/b43_STA/build-b43_STA.sh
#              http://www.broadcom.com/support/802.11/linux_sta.php
#              http://www.broadcom.com/docs/linux_sta/hybrid-portsrc_x86_32-v5_100_82_38.tar.gz
#              http://slackbuilds.org/slackbuilds/13.37/network/broadcom-sta/wl_linux.c-semaphore.patch (Patch for zenwalk kernel 2.6.37.4)
#
# packager: stillborn (stillbornDOTzenwalkATgmailDOTcom)
#
(
#------------------Set Some Variables
set -e -u -x
buildir=$(pwd)
softname="b43_STA"
softversion="5.100.82.38"
arch="i486"
#zenver="70.1"
kernel=`uname -r`
package="$softname-$softversion-$arch-`uname -r`"
dest="$buildir/$package"

INS644="install -o root -g root -m 644"
INS755="install -d -o root -g root -m 755"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $dest
rm -rf $buildir/X
$INS755 $dest/install

#-----------------Make the slack-desc files

cat <<EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler----------------------------------------------|
b43_STA: b43_STA - 802.11 Linux STA driver
b43_STA:
b43_STA: b43_STA package includes the kernel module 'wl', which 
b43_STA: contains the Broadcom-provided proprietary kernel driver 
b43_STA: that supports a number of their cards. Known supported
b43_STA: model numbers include the BCM4311, BCM4312, BCM4321, and
b43_STA: BCM4322 chipsets.
b43_STA:
b43_STA: Read the included LICENSE.txt file (placed in /usr/doc) 
b43_STA: before using this.
b43_STA: Built for kernel-`uname -r`
EOF

$INS755 $buildir/X
tar xf hybrid-portsrc_x86_32-v5_100_82_38.tar.gz --directory=X 
#unzip sta_5.60.48.36_2.6.34_multicast_kernel_patch.zip -d ./X
cd X
#patch -p0 < patch || exit 1
#patch -p0 < patch_hybrid_multicast || exit 1
#patch -p1 -i $buildir/b43_STA-zenfix.patch || exit 1
# Fix API change in newer kernels
patch -p1 < $buildir/wl_linux.c-semaphore.patch
make

$INS755 $dest/lib/modules/`uname -r`/kernel/drivers/net/wireless/$softname
$INS644 $buildir/X/wl.ko $dest/lib/modules/`uname -r`/kernel/drivers/net/wireless/$softname

$INS755 $dest/usr/src/$softname-$softversion
$INS644 $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

$INS755 $dest/usr/doc/$softname-$softversion
$INS644 $buildir/X/lib/LICENSE.txt $dest/usr/doc/$softname-$softversion

#-------------------Fix permissions
(
chown -R root:root $dest
cd $dest
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
)

#> helperline
(cd $dest;find . -printf "%y %m %u:%g %p %l\n") >$buildir/pkgtree.log

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
md5sum $package.txz > $package.md5
) 2>&1 | tee build-b43_STA.log.txt
